@@ -63,51 +63,39 @@ setMethod("rcond", signature(x = "dtrMatrix", norm = "missing"),
 	  .Call(dtrMatrix_rcond, x, "O"),
 	  valueClass = "numeric")
 
-if(getRversion() < "2.10.0" || R.version$`svn rev` < 49944) {
-    ## for now: still carry  'size' and 'LINPACK'
-setMethod("chol2inv", signature(x = "dtrMatrix"),
-          function (x, size = NCOL(x), LINPACK = FALSE)
-      {
-          if (!missing(size) || !missing(LINPACK))
-              warning("Arguments size and LINPACK are ignored for chol2inv\n\tmethods in the Matrix package")
-          if (x@diag != "N") x <- diagU2N(x)
-          .Call(dtrMatrix_chol2inv, x)
-      })
-} else {## chol2inv() has implicit generic in newer versions of R
 setMethod("chol2inv", signature(x = "dtrMatrix"),
 	  function (x, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      if (x@diag != "N") x <- diagU2N(x)
 	      .Call(dtrMatrix_chol2inv, x)
 	  })
-}
 
 setMethod("solve", signature(a = "dtrMatrix", b="missing"),
 	  function(a, b, ...) {
 	      ## warn, as e.g. CHMfactor have 'system' as third argument
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      .Call(dtrMatrix_solve, a)
 	  }, valueClass = "dtrMatrix")
 
 setMethod("solve", signature(a = "dtrMatrix", b="ddenseMatrix"),
 	  function(a, b, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      .Call(dtrMatrix_matrix_solve, a, b)
 	  }, valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dtrMatrix", b="dMatrix"),
 	  function(a, b, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      .Call(dtrMatrix_matrix_solve, a, as(b,"denseMatrix"))
 	  }, valueClass = "dgeMatrix")
 setMethod("solve", signature(a = "dtrMatrix", b="Matrix"),
 	  function(a, b, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      .Call(dtrMatrix_matrix_solve, a, as(as(b, "dMatrix"),
 						  "denseMatrix"))
 	  }, valueClass = "dgeMatrix")
@@ -115,7 +103,7 @@ setMethod("solve", signature(a = "dtrMatrix", b="Matrix"),
 setMethod("solve", signature(a = "dtrMatrix", b="matrix"),
 	  function(a, b, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      .Call(dtrMatrix_matrix_solve, a, b)
 	  }, valueClass = "dgeMatrix")
 
