@@ -7,12 +7,12 @@ SEXP CHMfactor_to_sparse(SEXP x)
     CHM_SP Lm;
     R_CheckStack();
 
-    /* cholmod_l_factor_to_sparse changes its first argument. Make a copy */
-    Lcp = cholmod_l_copy_factor(L, &c);
+    /* cholmod_factor_to_sparse changes its first argument. Make a copy */
+    Lcp = cholmod_copy_factor(L, &c);
     if (!(Lcp->is_ll))
-	if (!cholmod_l_change_factor(Lcp->xtype, 1, 0, 1, 1, Lcp, &c))
-	    error(_("cholmod_l_change_factor failed with status %d"), c.status);
-    Lm = cholmod_l_factor_to_sparse(Lcp, &c); cholmod_l_free_factor(&Lcp, &c);
+	if (!cholmod_change_factor(Lcp->xtype, 1, 0, 1, 1, Lcp, &c))
+	    error(_("cholmod_change_factor failed with status %d"), c.status);
+    Lm = cholmod_factor_to_sparse(Lcp, &c); cholmod_free_factor(&Lcp, &c);
     return chm_sparse_to_SEXP(Lm, 1/*do_free*/, -1/*uploT*/, 0/*Rkind*/,
 			      "N"/*non_unit*/, R_NilValue/*dimNames*/);
 }
@@ -28,7 +28,7 @@ SEXP CHMfactor_solve(SEXP a, SEXP b, SEXP system)
     if (!(sys--))		/* -- align with CHOLMOD defs */
 	error(_("system argument is not valid"));
 
-    X = cholmod_l_solve(sys, L, B, &c);
+    X = cholmod_solve(sys, L, B, &c);
     UNPROTECT(1);
     return chm_dense_to_SEXP(X, 1/*do_free*/, 0/*Rkind*/,
 			     GET_SLOT(bb, Matrix_DimNamesSym));
@@ -43,7 +43,7 @@ SEXP CHMfactor_spsolve(SEXP a, SEXP b, SEXP system)
 
     if (!(sys--))		/* -- align with CHOLMOD defs */
 	error(_("system argument is not valid"));
-    return chm_sparse_to_SEXP(cholmod_l_spsolve(sys, L, B, &c),
+    return chm_sparse_to_SEXP(cholmod_spsolve(sys, L, B, &c),
 			      1/*do_free*/, 0/*uploT*/, 0/*Rkind*/,
 			      "", GET_SLOT(b, Matrix_DimNamesSym));
 }
@@ -114,13 +114,13 @@ CHM_FR chm_factor_update(CHM_FR f, CHM_SP A, double mult)
     int ll = f->is_ll;
     double mm[2] = {0, 0};
     mm[0] = mult;
-    if (!cholmod_l_factorize_p(A, mm, (int*)NULL, 0 /*fsize*/, f, &c))
-	error(_("cholmod_l_factorize_p failed: status %d, minor %d of ncol %d"),
+    if (!cholmod_factorize_p(A, mm, (int*)NULL, 0 /*fsize*/, f, &c))
+	error(_("cholmod_factorize_p failed: status %d, minor %d of ncol %d"),
 	      c.status, f->minor, f->n);
     if (f->is_ll != ll)
-	if(!cholmod_l_change_factor(f->xtype, ll, f->is_super, 1 /*to_packed*/,
+	if(!cholmod_change_factor(f->xtype, ll, f->is_super, 1 /*to_packed*/,
 				    1 /*to_monotonic*/, f, &c))
-	   error(_("cholmod_l_change_factor failed"));
+	   error(_("cholmod_change_factor failed"));
     return f;
 }
 
@@ -130,7 +130,7 @@ SEXP CHMfactor_update(SEXP object, SEXP parent, SEXP mult)
     CHM_SP A = AS_CHM_SP__(parent);
     R_CheckStack();
 
-    Lcp = cholmod_l_copy_factor(L, &c);
+    Lcp = cholmod_copy_factor(L, &c);
     return chm_factor_to_SEXP(chm_factor_update(Lcp, A, asReal(mult)), 1);
 }
 
@@ -152,10 +152,10 @@ SEXP CHMfactor_ldetL2up(SEXP x, SEXP parent, SEXP mult)
     CHM_SP A = AS_CHM_SP__(parent);
     R_CheckStack();
 
-    Lcp = cholmod_l_copy_factor(L, &c);
+    Lcp = cholmod_copy_factor(L, &c);
     for (i = 0; i < nmult; i++)
 	aa[i] = chm_factor_ldetL2(chm_factor_update(Lcp, A, mm[i]));
-    cholmod_l_free_factor(&Lcp, &c);
+    cholmod_free_factor(&Lcp, &c);
     UNPROTECT(1);
     return ans;
 }
