@@ -204,8 +204,6 @@ void *CHOLMOD(free)	/* always returns NULL */
 	/* This assertion will fail if the user calls cholmod_malloc and
 	 * cholmod_free with mismatched memory sizes.  It shouldn't fail
 	 * otherwise. */
-	DEBUG (if (Common->malloc_count == 0 && Common->memory_inuse != 0)
-	    PRINT0 (("inuse: %d\n", Common->memory_inuse))) ;
 	ASSERT (IMPLIES (Common->malloc_count == 0, Common->memory_inuse == 0));
     }
     /* return NULL, and the caller should assign this to p.  This avoids
@@ -264,7 +262,7 @@ void *CHOLMOD(calloc)	/* returns pointer to the newly calloc'd block */
 	    Common->memory_inuse += (n * size) ;
 	    Common->memory_usage =
 		MAX (Common->memory_usage, Common->memory_inuse) ;
-	    PRINTM (("cholmod_calloc %p %d cnt: %d inuse %d\n",
+	    PRINTM (("cholmod_malloc %p %d cnt: %d inuse %d\n",
 		    p, n*size, Common->malloc_count, Common->memory_inuse)) ;
 	}
     }
@@ -354,8 +352,8 @@ void *CHOLMOD(realloc)	/* returns pointer to reallocated block */
 		 * CHOLMOD's notion of the size of the block, however. */
 		*n = nnew ;
 		PRINTM (("nnew <= nold failed, pretend to succeed\n")) ;
-		PRINTM (("cholmod_realloc_old: %p %d cnt: %d inuse %d\n"
-			 "cholmod_realloc_new: %p %d cnt: %d inuse %d\n",
+		PRINTM (("cholmod_free %p %d cnt: %d inuse %d\n"
+			 "cholmod_malloc %p %d cnt: %d inuse %d\n",
 		    p, nold*size, Common->malloc_count-1,
 				  Common->memory_inuse - nold*size,
 		    p, nnew*size, Common->malloc_count,
@@ -372,8 +370,8 @@ void *CHOLMOD(realloc)	/* returns pointer to reallocated block */
 	else
 	{
 	    /* success: return revised p and change the size of the block */
-	    PRINTM (("cholmod_realloc_old: %p %d cnt: %d inuse %d\n"
-		     "cholmod_realloc_new: %p %d cnt: %d inuse %d\n",
+	    PRINTM (("cholmod_free %p %d cnt: %d inuse %d\n"
+		     "cholmod_malloc %p %d cnt: %d inuse %d\n",
 		p, nold*size,    Common->malloc_count-1,
 				 Common->memory_inuse - nold*size,
 		pnew, nnew*size, Common->malloc_count,
@@ -406,10 +404,10 @@ int CHOLMOD(realloc_multiple)
     int nint,		/* number of int/UF_long blocks */
     int xtype,		/* CHOLMOD_PATTERN, _REAL, _COMPLEX, or _ZOMPLEX */
     /* ---- in/out --- */
-    void **I,		/* int or UF_long block */
-    void **J,		/* int or UF_long block */
-    void **X,		/* complex or double block */
-    void **Z,		/* zomplex case only: double block */
+    void **Iblock,	/* int or UF_long block */
+    void **Jblock,	/* int or UF_long block */
+    void **Xblock,	/* complex or double block */
+    void **Zblock,	/* zomplex case only: double block */
     size_t *nold_p,	/* current size of the I,J,X,Z blocks on input,
 			 * nnew on output if successful */
     /* --------------- */
@@ -442,26 +440,30 @@ int CHOLMOD(realloc_multiple)
 
     if (nint > 0)
     {
-	*I = CHOLMOD(realloc) (nnew, sizeof (Int), *I, &i, Common) ;
+	*Iblock = CHOLMOD(realloc) (nnew, sizeof (Int), *Iblock, &i, Common) ;
     }
     if (nint > 1)
     {
-	*J = CHOLMOD(realloc) (nnew, sizeof (Int), *J, &j, Common) ;
+	*Jblock = CHOLMOD(realloc) (nnew, sizeof (Int), *Jblock, &j, Common) ;
     }
 
     switch (xtype)
     {
 	case CHOLMOD_REAL:
-	    *X = CHOLMOD(realloc) (nnew, sizeof (double), *X, &x, Common) ;
+	    *Xblock = CHOLMOD(realloc) (nnew, sizeof (double), *Xblock, &x,
+                    Common) ;
 	    break ;
 
 	case CHOLMOD_COMPLEX:
-	    *X = CHOLMOD(realloc) (nnew, 2*sizeof (double), *X, &x, Common) ;
+	    *Xblock = CHOLMOD(realloc) (nnew, 2*sizeof (double), *Xblock, &x,
+                    Common) ;
 	    break ;
 
 	case CHOLMOD_ZOMPLEX:
-	    *X = CHOLMOD(realloc) (nnew, sizeof (double), *X, &x, Common) ;
-	    *Z = CHOLMOD(realloc) (nnew, sizeof (double), *Z, &z, Common) ;
+	    *Xblock = CHOLMOD(realloc) (nnew, sizeof (double), *Xblock, &x,
+                    Common) ;
+	    *Zblock = CHOLMOD(realloc) (nnew, sizeof (double), *Zblock, &z,
+                    Common) ;
 	    break ;
     }
 
@@ -474,26 +476,30 @@ int CHOLMOD(realloc_multiple)
 
 	    if (nint > 0)
 	    {
-		*I = CHOLMOD(free) (i, sizeof (Int), *I, Common) ;
+		*Iblock = CHOLMOD(free) (i, sizeof (Int), *Iblock, Common) ;
 	    }
 	    if (nint > 1)
 	    {
-		*J = CHOLMOD(free) (j, sizeof (Int), *J, Common) ;
+		*Jblock = CHOLMOD(free) (j, sizeof (Int), *Jblock, Common) ;
 	    }
 
 	    switch (xtype)
 	    {
 		case CHOLMOD_REAL:
-		    *X = CHOLMOD(free) (x, sizeof (double), *X, Common) ;
+		    *Xblock = CHOLMOD(free) (x, sizeof (double), *Xblock,
+                            Common) ;
 		    break ;
 
 		case CHOLMOD_COMPLEX:
-		    *X = CHOLMOD(free) (x, 2*sizeof (double), *X, Common) ;
+		    *Xblock = CHOLMOD(free) (x, 2*sizeof (double), *Xblock,
+                            Common) ;
 		    break ;
 
 		case CHOLMOD_ZOMPLEX:
-		    *X = CHOLMOD(free) (x, sizeof (double), *X, Common) ;
-		    *Z = CHOLMOD(free) (x, sizeof (double), *Z, Common) ;
+		    *Xblock = CHOLMOD(free) (x, sizeof (double), *Xblock,
+                            Common) ;
+		    *Zblock = CHOLMOD(free) (x, sizeof (double), *Zblock,
+                            Common) ;
 		    break ;
 	    }
 
@@ -502,30 +508,32 @@ int CHOLMOD(realloc_multiple)
 	{
 	    if (nint > 0)
 	    {
-		*I = CHOLMOD(realloc) (nold, sizeof (Int), *I, &i, Common) ;
+		*Iblock = CHOLMOD(realloc) (nold, sizeof (Int), *Iblock, &i,
+                            Common) ;
 	    }
 	    if (nint > 1)
 	    {
-		*J = CHOLMOD(realloc) (nold, sizeof (Int), *J, &j, Common) ;
+		*Jblock = CHOLMOD(realloc) (nold, sizeof (Int), *Jblock, &j,
+                            Common) ;
 	    }
 
 	    switch (xtype)
 	    {
 		case CHOLMOD_REAL:
-		    *X = CHOLMOD(realloc) (nold, sizeof (double), *X, &x,
-			    Common) ;
+		    *Xblock = CHOLMOD(realloc) (nold, sizeof (double),
+                            *Xblock, &x, Common) ;
 		    break ;
 
 		case CHOLMOD_COMPLEX:
-		    *X = CHOLMOD(realloc) (nold, 2*sizeof (double), *X, &x,
-			    Common) ;
+		    *Xblock = CHOLMOD(realloc) (nold, 2*sizeof (double),
+                            *Xblock, &x, Common) ;
 		    break ;
 
 		case CHOLMOD_ZOMPLEX:
-		    *X = CHOLMOD(realloc) (nold, sizeof (double), *X, &x,
-			    Common) ;
-		    *Z = CHOLMOD(realloc) (nold, sizeof (double), *Z, &z,
-			    Common) ;
+		    *Xblock = CHOLMOD(realloc) (nold, sizeof (double),
+                            *Xblock, &x, Common) ;
+		    *Zblock = CHOLMOD(realloc) (nold, sizeof (double),
+                            *Zblock, &z, Common) ;
 		    break ;
 	    }
 
@@ -539,8 +547,8 @@ int CHOLMOD(realloc_multiple)
 	/* New space was allocated.  Clear the first entry so that valgrind
 	 * doesn't complain about its access in change_complexity
 	 * (Core/cholmod_complex.c). */
-	xx = *X ;
-	zz = *Z ;
+	xx = *Xblock ;
+	zz = *Zblock ;
 	switch (xtype)
 	{
 	    case CHOLMOD_REAL:
