@@ -1,4 +1,5 @@
 			/* Sparse matrices in compressed column-oriented form */
+
 #include "Csparse.h"
 #include "Tsparse.h"
 #include "chm_common.h"
@@ -136,7 +137,7 @@ SEXP Rsparse_validate(SEXP x)
 	    }
     }
     if (!sorted)
-	/* cannot easily use cholmod_l_sort(.) ... -> "error out" :*/
+	/* cannot easily use cholmod_sort(.) ... -> "error out" :*/
 	return mkString(_("slot j is not increasing inside a column"));
     else if(!strictly) /* sorted, but not strictly */
 	return mkString(_("slot j is not *strictly* increasing inside a column"));
@@ -154,7 +155,7 @@ SEXP Csparse_to_dense(SEXP x)
     /* This loses the symmetry property, since cholmod_dense has none,
      * BUT, much worse (FIXME!), it also transforms CHOLMOD_PATTERN ("n") matrices
      * to numeric (CHOLMOD_REAL) ones : */
-    CHM_DN chxd = cholmod_l_sparse_to_dense(chxs, &c);
+    CHM_DN chxd = cholmod_sparse_to_dense(chxs, &c);
     int Rkind = (chxs->xtype == CHOLMOD_PATTERN)? -1 : Real_kind(x);
     R_CheckStack();
 
@@ -165,7 +166,7 @@ SEXP Csparse_to_dense(SEXP x)
 SEXP Csparse_to_nz_pattern(SEXP x, SEXP tri)
 {
     CHM_SP chxs = AS_CHM_SP__(x);
-    CHM_SP chxcp = cholmod_l_copy(chxs, chxs->stype, CHOLMOD_PATTERN, &c);
+    CHM_SP chxcp = cholmod_copy(chxs, chxs->stype, CHOLMOD_PATTERN, &c);
     int tr = asLogical(tri);
     R_CheckStack();
 
@@ -230,14 +231,14 @@ SEXP nz2Csparse(SEXP x, enum x_slot_kind r_kind)
 
 SEXP Csparse_to_matrix(SEXP x)
 {
-    return chm_dense_to_matrix(cholmod_l_sparse_to_dense(AS_CHM_SP__(x), &c),
+    return chm_dense_to_matrix(cholmod_sparse_to_dense(AS_CHM_SP__(x), &c),
 			       1 /*do_free*/, GET_SLOT(x, Matrix_DimNamesSym));
 }
 
 SEXP Csparse_to_Tsparse(SEXP x, SEXP tri)
 {
     CHM_SP chxs = AS_CHM_SP__(x);
-    CHM_TR chxt = cholmod_l_sparse_to_triplet(chxs, &c);
+    CHM_TR chxt = cholmod_sparse_to_triplet(chxs, &c);
     int tr = asLogical(tri);
     int Rkind = (chxs->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
     R_CheckStack();
@@ -257,7 +258,7 @@ SEXP Csparse_symmetric_to_general(SEXP x)
 
     if (!(chx->stype))
 	error(_("Nonsymmetric matrix in Csparse_symmetric_to_general"));
-    chgx = cholmod_l_copy(chx, /* stype: */ 0, chx->xtype, &c);
+    chgx = cholmod_copy(chx, /* stype: */ 0, chx->xtype, &c);
     /* xtype: pattern, "real", complex or .. */
     return chm_sparse_to_SEXP(chgx, 1, 0, Rkind, "",
 			      GET_SLOT(x, Matrix_DimNamesSym));
@@ -270,7 +271,7 @@ SEXP Csparse_general_to_symmetric(SEXP x, SEXP uplo)
     int Rkind = (chx->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
     R_CheckStack();
 
-    chgx = cholmod_l_copy(chx, /* stype: */ uploT, chx->xtype, &c);
+    chgx = cholmod_copy(chx, /* stype: */ uploT, chx->xtype, &c);
     /* xtype: pattern, "real", complex or .. */
     return chm_sparse_to_SEXP(chgx, 1, 0, Rkind, "",
 			      GET_SLOT(x, Matrix_DimNamesSym));
@@ -282,7 +283,7 @@ SEXP Csparse_transpose(SEXP x, SEXP tri)
      *       since cholmod (& cs) lacks sparse 'int' matrices */
     CHM_SP chx = AS_CHM_SP__(x);
     int Rkind = (chx->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
-    CHM_SP chxt = cholmod_l_transpose(chx, chx->xtype, &c);
+    CHM_SP chxt = cholmod_transpose(chx, chx->xtype, &c);
     SEXP dn = PROTECT(duplicate(GET_SLOT(x, Matrix_DimNamesSym))), tmp;
     int tr = asLogical(tri);
     R_CheckStack();
@@ -301,7 +302,7 @@ SEXP Csparse_Csparse_prod(SEXP a, SEXP b)
     CHM_SP
 	cha = AS_CHM_SP(a),
 	chb = AS_CHM_SP(b),
-	chc = cholmod_l_ssmult(cha, chb, /*out_stype:*/ 0,
+	chc = cholmod_ssmult(cha, chb, /*out_stype:*/ 0,
 			       /* values:= is_numeric (T/F) */ cha->xtype > 0,
 			       /*out sorted:*/ 1, &c);
     const char *cl_a = class_P(a), *cl_b = class_P(b);
@@ -352,10 +353,10 @@ SEXP Csparse_Csparse_crossprod(SEXP a, SEXP b, SEXP trans)
     SEXP dn = PROTECT(allocVector(VECSXP, 2));
     R_CheckStack();
 
-    chTr = cholmod_l_transpose((tr) ? chb : cha, chb->xtype, &c);
-    chc = cholmod_l_ssmult((tr) ? cha : chTr, (tr) ? chTr : chb,
+    chTr = cholmod_transpose((tr) ? chb : cha, chb->xtype, &c);
+    chc = cholmod_ssmult((tr) ? cha : chTr, (tr) ? chTr : chb,
 			 /*out_stype:*/ 0, cha->xtype, /*out sorted:*/ 1, &c);
-    cholmod_l_free_sparse(&chTr, &c);
+    cholmod_free_sparse(&chTr, &c);
 
     /* Preserve triangularity and unit-triangularity if appropriate;
      * see Csparse_Csparse_prod() for comments */
@@ -381,7 +382,7 @@ SEXP Csparse_dense_prod(SEXP a, SEXP b)
     CHM_SP cha = AS_CHM_SP(a);
     SEXP b_M = PROTECT(mMatrix_as_dgeMatrix(b));
     CHM_DN chb = AS_CHM_DN(b_M);
-    CHM_DN chc = cholmod_l_allocate_dense(cha->nrow, chb->ncol, cha->nrow,
+    CHM_DN chc = cholmod_allocate_dense(cha->nrow, chb->ncol, cha->nrow,
 					chb->xtype, &c);
     SEXP dn = PROTECT(allocVector(VECSXP, 2));
     double one[] = {1,0}, zero[] = {0,0};
@@ -398,7 +399,7 @@ SEXP Csparse_dense_prod(SEXP a, SEXP b)
 	SEXP da = PROTECT(nz2Csparse(a, x_double)); nprot++;
 	cha = AS_CHM_SP(da);
     }
-    cholmod_l_sdmult(cha, 0, one, zero, chb, chc, &c);
+    cholmod_sdmult(cha, 0, one, zero, chb, chc, &c);
     SET_VECTOR_ELT(dn, 0,	/* establish dimnames */
 		   duplicate(VECTOR_ELT(GET_SLOT(a, Matrix_DimNamesSym), 0)));
     SET_VECTOR_ELT(dn, 1,
@@ -412,7 +413,7 @@ SEXP Csparse_dense_crossprod(SEXP a, SEXP b)
     CHM_SP cha = AS_CHM_SP(a);
     SEXP b_M = PROTECT(mMatrix_as_dgeMatrix(b));
     CHM_DN chb = AS_CHM_DN(b_M);
-    CHM_DN chc = cholmod_l_allocate_dense(cha->ncol, chb->ncol, cha->ncol,
+    CHM_DN chc = cholmod_allocate_dense(cha->ncol, chb->ncol, cha->ncol,
 					chb->xtype, &c);
     SEXP dn = PROTECT(allocVector(VECSXP, 2)); int nprot = 2;
     double one[] = {1,0}, zero[] = {0,0};
@@ -422,7 +423,7 @@ SEXP Csparse_dense_crossprod(SEXP a, SEXP b)
 	SEXP da = PROTECT(nz2Csparse(a, x_double)); nprot++;
 	cha = AS_CHM_SP(da);
     }
-    cholmod_l_sdmult(cha, 1, one, zero, chb, chc, &c);
+    cholmod_sdmult(cha, 1, one, zero, chb, chc, &c);
     SET_VECTOR_ELT(dn, 0,	/* establish dimnames */
 		   duplicate(VECTOR_ELT(GET_SLOT(a, Matrix_DimNamesSym), 1)));
     SET_VECTOR_ELT(dn, 1,
@@ -445,21 +446,21 @@ SEXP Csparse_crossprod(SEXP x, SEXP trans, SEXP triplet)
 #endif
     CHM_SP chcp, chxt,
 	chx = (trip ?
-	       cholmod_l_triplet_to_sparse(cht, cht->nnz, &c) :
+	       cholmod_triplet_to_sparse(cht, cht->nnz, &c) :
 	       AS_CHM_SP(x));
     SEXP dn = PROTECT(allocVector(VECSXP, 2));
     R_CheckStack();
 
-    if (!tr) chxt = cholmod_l_transpose(chx, chx->xtype, &c);
-    chcp = cholmod_l_aat((!tr) ? chxt : chx, (int *) NULL, 0, chx->xtype, &c);
+    if (!tr) chxt = cholmod_transpose(chx, chx->xtype, &c);
+    chcp = cholmod_aat((!tr) ? chxt : chx, (int *) NULL, 0, chx->xtype, &c);
     if(!chcp) {
 	UNPROTECT(1);
-	error(_("Csparse_crossprod(): error return from cholmod_l_aat()"));
+	error(_("Csparse_crossprod(): error return from cholmod_aat()"));
     }
-    cholmod_l_band_inplace(0, chcp->ncol, chcp->xtype, chcp, &c);
+    cholmod_band_inplace(0, chcp->ncol, chcp->xtype, chcp, &c);
     chcp->stype = 1;
-    if (trip) cholmod_l_free_sparse(&chx, &c);
-    if (!tr) cholmod_l_free_sparse(&chxt, &c);
+    if (trip) cholmod_free_sparse(&chx, &c);
+    if (!tr) cholmod_free_sparse(&chxt, &c);
     SET_VECTOR_ELT(dn, 0,	/* establish dimnames */
 		   duplicate(VECTOR_ELT(GET_SLOT(x, Matrix_DimNamesSym),
 					(tr) ? 0 : 1)));
@@ -472,19 +473,21 @@ SEXP Csparse_crossprod(SEXP x, SEXP trans, SEXP triplet)
     return chm_sparse_to_SEXP(chcp, 1, 0, 0, "", dn);
 }
 
+/* Csparse_drop(x, tol):  drop entries with absolute value < tol, i.e,
+*  at least all "explicit" zeros */
 SEXP Csparse_drop(SEXP x, SEXP tol)
 {
     const char *cl = class_P(x);
     /* dtCMatrix, etc; [1] = the second character =?= 't' for triangular */
     int tr = (cl[1] == 't');
     CHM_SP chx = AS_CHM_SP__(x);
-    CHM_SP ans = cholmod_l_copy(chx, chx->stype, chx->xtype, &c);
+    CHM_SP ans = cholmod_copy(chx, chx->stype, chx->xtype, &c);
     double dtol = asReal(tol);
     int Rkind = (chx->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
     R_CheckStack();
 
-    if(!cholmod_l_drop(dtol, ans, &c))
-	error(_("cholmod_l_drop() failed"));
+    if(!cholmod_drop(dtol, ans, &c))
+	error(_("cholmod_drop() failed"));
     return chm_sparse_to_SEXP(ans, 1,
 			      tr ? ((*uplo_P(x) == 'U') ? 1 : -1) : 0,
 			      Rkind, tr ? diag_P(x) : "",
@@ -500,7 +503,7 @@ SEXP Csparse_horzcat(SEXP x, SEXP y)
     R_CheckStack();
 
     /* TODO: currently drops dimnames - and we fix at R level */
-    return chm_sparse_to_SEXP(cholmod_l_horzcat(chx, chy, 1, &c),
+    return chm_sparse_to_SEXP(cholmod_horzcat(chx, chy, 1, &c),
 			      1, 0, Rkind, "", R_NilValue);
 }
 
@@ -513,7 +516,7 @@ SEXP Csparse_vertcat(SEXP x, SEXP y)
     R_CheckStack();
 
     /* TODO: currently drops dimnames - and we fix at R level */
-    return chm_sparse_to_SEXP(cholmod_l_vertcat(chx, chy, 1, &c),
+    return chm_sparse_to_SEXP(cholmod_vertcat(chx, chy, 1, &c),
 			      1, 0, Rkind, "", R_NilValue);
 }
 
@@ -521,7 +524,7 @@ SEXP Csparse_band(SEXP x, SEXP k1, SEXP k2)
 {
     CHM_SP chx = AS_CHM_SP__(x);
     int Rkind = (chx->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
-    CHM_SP ans = cholmod_l_band(chx, asInteger(k1), asInteger(k2), chx->xtype, &c);
+    CHM_SP ans = cholmod_band(chx, asInteger(k1), asInteger(k2), chx->xtype, &c);
     R_CheckStack();
 
     return chm_sparse_to_SEXP(ans, 1, 0, Rkind, "",
@@ -539,14 +542,14 @@ SEXP Csparse_diagU2N(SEXP x)
     }
     else { /* unit triangular (diag='U'): "fill the diagonal" & diag:= "N" */
 	CHM_SP chx = AS_CHM_SP__(x);
-	CHM_SP eye = cholmod_l_speye(chx->nrow, chx->ncol, chx->xtype, &c);
+	CHM_SP eye = cholmod_speye(chx->nrow, chx->ncol, chx->xtype, &c);
 	double one[] = {1, 0};
-	CHM_SP ans = cholmod_l_add(chx, eye, one, one, TRUE, TRUE, &c);
+	CHM_SP ans = cholmod_add(chx, eye, one, one, TRUE, TRUE, &c);
 	int uploT = (*uplo_P(x) == 'U') ? 1 : -1;
 	int Rkind = (chx->xtype != CHOLMOD_PATTERN) ? Real_kind(x) : 0;
 
 	R_CheckStack();
-	cholmod_l_free_sparse(&eye, &c);
+	cholmod_free_sparse(&eye, &c);
 	return chm_sparse_to_SEXP(ans, 1, uploT, Rkind, "N",
 				  GET_SLOT(x, Matrix_DimNamesSym));
     }
@@ -600,9 +603,9 @@ SEXP Csparse_submatrix(SEXP x, SEXP i, SEXP j)
 
     if (chx->stype) /* symmetricMatrix */
 	/* for now, cholmod_submatrix() only accepts "generalMatrix" */
-	chx = cholmod_l_copy(chx, /* stype: */ 0, chx->xtype, &c);
+	chx = cholmod_copy(chx, /* stype: */ 0, chx->xtype, &c);
 
-    return chm_sparse_to_SEXP(cholmod_l_submatrix(chx,
+    return chm_sparse_to_SEXP(cholmod_submatrix(chx,
 				(rsize < 0) ? NULL : INTEGER(i), rsize,
 			        (csize < 0) ? NULL : INTEGER(j), csize,
 						  TRUE, TRUE, &c),
@@ -610,6 +613,23 @@ SEXP Csparse_submatrix(SEXP x, SEXP i, SEXP j)
 			      /* FIXME: drops dimnames */ R_NilValue);
 }
 
+#define _d_Csp_
+#include "t_Csparse_subassign.c"
+
+#define _l_Csp_
+#include "t_Csparse_subassign.c"
+
+#define _i_Csp_
+#include "t_Csparse_subassign.c"
+
+#define _n_Csp_
+#include "t_Csparse_subassign.c"
+
+#define _z_Csp_
+#include "t_Csparse_subassign.c"
+
+
+
 SEXP Csparse_MatrixMarket(SEXP x, SEXP fname)
 {
     FILE *f = fopen(CHAR(asChar(fname)), "w");
@@ -617,9 +637,9 @@ SEXP Csparse_MatrixMarket(SEXP x, SEXP fname)
     if (!f)
 	error(_("failure to open file \"%s\" for writing"),
 	      CHAR(asChar(fname)));
-    if (!cholmod_l_write_sparse(f, AS_CHM_SP(x),
+    if (!cholmod_write_sparse(f, AS_CHM_SP(x),
 			      (CHM_SP)NULL, (char*) NULL, &c))
-	error(_("cholmod_l_write_sparse returned error code"));
+	error(_("cholmod_write_sparse returned error code"));
     fclose(f);
     return R_NilValue;
 }
@@ -786,7 +806,7 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
 		j = ij;
 		ncol = np;
 	    }
-				/* Expand p to 0-based indices */
+	    /* Expand p to 0-based indices */
 	    for (int ii = 0; ii < np; ii++)
 		for (int jj = p[ii]; jj < p[ii + 1]; jj++) ij[jj] = ii;
 	} else {
@@ -795,7 +815,7 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
 		      nnz);
 	}
     }
-				/* calculate nrow and ncol */
+    /* calculate nrow and ncol */
     if (nrow < 0) {
 	for (int ii = 0; ii < nnz; ii++) {
 	    int i1 = i[ii] + (index1 ? 0 : 1); /* 1-based index */
@@ -814,7 +834,7 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
 	if (dims[0] > nrow) nrow = dims[0];
 	if (dims[1] > ncol) ncol = dims[1];
     }
-				/* check the class name */
+    /* check the class name */
     if (strlen(cls) != 8)
 	error(_("strlen of cls argument = %d, should be 8"), strlen(cls));
     if (!strcmp(cls + 2, "CMatrix"))
@@ -822,19 +842,19 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
     switch(cls[0]) {
     case 'd':
     case 'l':
-	   xtype = CHOLMOD_REAL;
-	   break;
+	xtype = CHOLMOD_REAL;
+    break;
     case 'n':
-	   xtype = CHOLMOD_PATTERN;
-	   break;
+	xtype = CHOLMOD_PATTERN;
+	break;
     default:
-	   error(_("cls = \"%s\" must begin with 'd', 'l' or 'n'"), cls);
+	error(_("cls = \"%s\" must begin with 'd', 'l' or 'n'"), cls);
     }
     if (cls[1] != 'g')
 	error(_("Only 'g'eneral sparse matrix types allowed"));
-				/* allocate and populate the triplet */
-    T = cholmod_l_allocate_triplet((size_t)nrow, (size_t)ncol, (size_t)nnz, 0,
-				    xtype, &c);
+    /* allocate and populate the triplet */
+    T = cholmod_allocate_triplet((size_t)nrow, (size_t)ncol, (size_t)nnz, 0,
+				 xtype, &c);
     T->x = x;
     tri = (int*)T->i;
     trj = (int*)T->j;
@@ -842,14 +862,14 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
 	tri[ii] = i[ii] - ((!mi && index1) ? 1 : 0);
 	trj[ii] = j[ii] - ((!mj && index1) ? 1 : 0);
     }
-				/* create the cholmod_sparse structure */
-    A = cholmod_l_triplet_to_sparse(T, nnz, &c);
-    cholmod_l_free_triplet(&T, &c);
-				/* copy the information to the SEXP */
+    /* create the cholmod_sparse structure */
+    A = cholmod_triplet_to_sparse(T, nnz, &c);
+    cholmod_free_triplet(&T, &c);
+    /* copy the information to the SEXP */
     ans = PROTECT(NEW_OBJECT(MAKE_CLASS(cls)));
 /* FIXME: This has been copied from chm_sparse_to_SEXP in chm_common.c */
-				/* allocate and copy common slots */
-    nnz = cholmod_l_nnz(A, &c);
+    /* allocate and copy common slots */
+    nnz = cholmod_nnz(A, &c);
     dims = INTEGER(ALLOC_SLOT(ans, Matrix_DimSym, INTSXP, 2));
     dims[0] = A->nrow; dims[1] = A->ncol;
     Memcpy(INTEGER(ALLOC_SLOT(ans, Matrix_pSym, INTSXP, A->ncol + 1)), (int*)A->p, A->ncol + 1);
@@ -861,7 +881,8 @@ SEXP create_Csparse(char* cls, int* i, int* j, int* p, int np,
     case 'l':
 	error(_("code not yet written for cls = \"lgCMatrix\""));
     }
-    cholmod_l_free_sparse(&A, &c);
+/* FIXME: dimnames are *NOT* put there yet (if non-NULL) */
+    cholmod_free_sparse(&A, &c);
     UNPROTECT(1);
     return ans;
 }
