@@ -59,6 +59,16 @@ I1[1,1] <- i1[1, ] <- I [ ,1] <- NA
 stopifnot(identical3(I,i1,I1))
 image(d4) # gave infinite recursion
 
+assertError( Matrix(factor(letters)) )
+mlp <- matrix(.leap.seconds)## 24 x 1 numeric matrix
+Mlp <- Matrix(.leap.seconds)
+assert.EQ.mat(Mlp, mlp)
+if(FALSE) { ## TODO -- once R itself does better ...
+    .Leap.seconds <- as.POSIXlt(.leap.seconds)
+    mLp <- matrix(.Leap.seconds)##  24 x 1  list each of length 24 -- yuck!!!
+    MLp <- Matrix(.Leap.seconds)## --> error (for now)
+}
+
 I <- Diagonal(3); I[,1] <- NA; I[2,2] <- NA ; I[3,] <- NaN
 stopifnot(isValid(I, "sparseMatrix"))
 I # gave error in printSpMatrix() - because of R bug in format.info()
@@ -147,9 +157,6 @@ stopifnot(class(t5) == "dtCMatrix",
 sm <- selectMethod(coerce, c("dgCMatrix", "triangularMatrix"), verbose=TRUE)
 stopifnot(identical(sm(g5), t5))
 
-if(getRversion() < "2.9.0") ## 2.9.0++ has "Note"s instead of ambiguity "Warning"s:
-    options(op)
-
 
 (t1 <- new("dtTMatrix", x= c(3,7), i= 0:1, j=3:2,
            Dim= as.integer(c(4,4))))
@@ -653,6 +660,16 @@ nt <- triu(nn)
 n3 <- as(nt, "lsparseMatrix")
 da <- nt + t(nt)
 dm <- nt * t(nt) + da
+##
+mnt <- as(nt, "matrix")
+m <- rbind(v <- 2:3)
+assert.EQ.mat(nt %*% v, mnt %*% v)
+assert.EQ.mat(v %*% nt, v %*% mnt)
+assert.EQ.mat( crossprod(nt, v),  crossprod(mnt,v))
+assert.EQ.mat( crossprod(v, nt),  crossprod(v,mnt))
+assert.EQ.mat(tcrossprod(v, nt), tcrossprod(v,mnt))
+assert.EQ.mat(tcrossprod(nt, m), tcrossprod(mnt, m))
+##
 stopifnot(isValid(ms, "dsTMatrix"),
           as(ms0,"matrix") == as(ll, "matrix"), # coercing num |-> log
 	  as(lt, "matrix") == as(ll, "matrix"),
@@ -692,6 +709,7 @@ D. <- Diagonal(x= c(-2,3:4)); D.[lower.tri(D.)] <- 1:3 ; D.
 D0 <- Diagonal(x= 0:3);       D0[upper.tri(D0)] <- 1:6 ; D0
 stopifnot(all.equal(list(modulus = structure(24, logarithm = FALSE), sign = -1L),
                     unclass(determinant(D.,FALSE)), tol=1e-15),
+	  det(Matrix(0,1)) == 0,
           all.equal(list(modulus = structure(0, logarithm = FALSE), sign = 1L),
                     unclass(determinant(D0,FALSE)), tol=0)
           )
@@ -735,8 +753,14 @@ assert.EQ.mat(solve(solve(p.)), as(p., "matrix"))
 dimnames(p.)[[1]] <- paste(1:4)
 ii <- is.na(p.)
 stopifnot(all(!ii), !any(as(ii, "denseMatrix")))# used to fail
-if(getRversion() >= "2.9.0") # (otherwise have done it above)
-    options(op)
+
+lst <- ls()
+table(istri <- sapply(lst, function(.) is(get(.),"triangularMatrix")))
+table(triC <- sapply(lst[istri], function(.) class(get(.))))
+table(uniC <- sapply(lst[istri], function(.) get(.)@diag == "U"))
+lsUtr <- lst[istri][uniC]
+(di <- sapply(lsUtr, function(.) dim(get(.))))
+## TODO: use %*%, crossprod(), .. on all those  4 x 4 -- and check "triangular rules"
 
 cat('Time elapsed: ', (.pt <- proc.time()),'\n') # "stats"
 ##
@@ -749,3 +773,14 @@ for(nm in ls()) if(is(.m <- get(nm), "Matrix")) {
 cat('Time elapsed: ', proc.time() - .pt,'\n') # "stats"
 
 if(!interactive()) warnings()
+
+## Platform - and other such info -- so we find it in old saved outputs
+SysI <- Sys.info()
+structure(Sys.info()[c(4,5,1:3)], class="simple.list")
+sessionInfo()
+c(Matrix = packageDescription("Matrix")$Built)
+if(SysI[["sysname"]] == "Linux" && require("sfsmisc")) local({
+    nn <- names(.Sc <- sfsmisc::Sys.cpuinfo())
+    nn <- names(.Sc <- .Sc[nn != "flags"])
+    print(.Sc[grep("\\.[0-9]$", nn, invert=TRUE)])
+})
