@@ -33,11 +33,12 @@ str(im)
 (mi <- cBind(m2, I = 1000))
 str(mi)
 (m1m <- cBind(m,I=100,m2))
+showProc.time()
 
 ### --- Diagonal / Sparse - had bugs
 
 D4 <- Diagonal(4)
-(D4T <- as(D4, "sparseMatrix"))
+(D4T <- as(D4, "TsparseMatrix"))
 D4C <- as(D4T, "CsparseMatrix")
 c1 <- Matrix(0+0:3, 4, sparse=TRUE) ; r1 <- t(c1); r1
 
@@ -53,6 +54,7 @@ stopifnot(identical(Matrix(cbind(diag(3),0)), cbind2(Diagonal(3),0)),
 	  is(d4, "sparseMatrix"), is(m4, "sparseMatrix"),
 	  identical(t(d4), cBind(Diagonal(4),     0:3)),
 	  identical(t(m4), rBind(Diagonal(x=-1:2), 0:3)))
+showProc.time()
 
 ### --- Sparse Matrices ---
 
@@ -79,6 +81,7 @@ for(v in list(0, 2, 1:0))
         }
         cat("\n")
     }
+showProc.time()
 
 cBind(0, mC); cBind(mC, 0)
 cBind(0, mT); cBind(mT, 2)
@@ -92,6 +95,13 @@ stopifnot(identical3(cc, cBind(mT, 0,7,0, diag(nr), 0),
 cBind(mC, 1, 100*mC, 0, 0:2)
 cBind(mT, 1, 0, mT+10*mT, 0, 0:2)
 
+## logical (sparse) - should remain logical :
+L5 <- Diagonal(n = 5, x = TRUE); v5 <- rep(x = c(FALSE,TRUE), length = ncol(L5))
+stopifnot(is(show(rBind(L5,v5)), "lsparseMatrix"),
+	  is(show(cBind(v5,L5)), "lsparseMatrix"),
+	  is(rBind(L5, 2* v5), "dsparseMatrix"),
+	  is(cBind(2* v5, L5), "dsparseMatrix"))
+
 ## print() / show() of  non-structural zeros:
 (m <- Matrix(c(0, 0, 2:0), 3, 5))
 (m2 <- cBind(m,m))
@@ -104,4 +114,4 @@ for(i in 1:6) {
 m4 ## now show some non-structural zeros:
 
 
-cat('Time elapsed: ', proc.time(),'\n') # for ``statistical reasons''
+showProc.time()
